pilas.demos.piezas.Piezas

Package pilas :: Package demos :: Module piezas :: Class Piezas |
[hide private]
[frames] | no frames]

# Class Piezas

source code

                 object --+
                          |
    escena.escena_base.Base --+
                              |
                             Piezas

Representa la escena de rompecabezas.

La escena comienza con una imagen que se descompone en muchos actores Pieza.

Instance Methods | [hide private]
__init__(self, ruta_a_la_imagen=`'``fondos/noche.jpg``'`, filas=4, columnas=4, al_terminar=None) x.__init__(...) initializes x; see help(type(x)) for signature | source code
iniciar(self) Este método debe ser reimplementado en todas las clases que hereden de ella. | source code
crear_piezas(self, grilla, filas, columnas) Genera todas las piezas en base al tamaño del constructor. | source code
al_hacer_click(self, evento) Atiente cualquier click que realice el usuario en la pantalla. | source code
al_soltar_el_click(self, evento) | source code
al_mover_el_mouse(self, evento) | source code
conectar(self, pieza_a, pieza_b) | source code
Inherited from `escena.escena_base.Base`: `pausar`, `reanudar` Inherited from `escena.escena_base.Base` (private): `_actualizar_eventos`, `_actualizar_fisica`, `_limpiar`, `_pausar_fisica`, `_reanudar_fisica` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, ruta_a_la_imagen=`'``fondos/noche.jpg``'`, filas=4, columnas=4, al_terminar=None) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### iniciar(self) | source code
Este método debe ser reimplementado en todas las clases que hereden de ella.
    >>>    def iniciar(self):
    >>>        fondo = pilas.fondos.Color(pilas.colores.grisclaro)
Overrides: escena.escena_base.Base.iniciar (inherited documentation)